import { BREAKPOINT_LG, BREAKPOINT_MD, BREAKPOINT_SM, BREAKPOINT_XL } from './breakpoints';

export const FONTS = {
  body: 'Inter',
  display: 'Raleway',
  heading: 'Inter',
  mono: 'Space Mono',
};

export const FONT_SIZES = {
  xs: '0.75rem',
  sm: '0.875rem',
  md: '1rem',
  lg: '1.125rem',
  xl: '1.25rem',
  '2xl': '1.375rem',
  '3xl': '1.75rem',
  '4xl': '1.875rem',
  '5xl': '2rem',
  '6xl': '2.75rem',
  '7xl': '3.5rem',
  '8xl': '6rem',
  '9xl': '8rem',
};

export const LINE_HEIGHTS = {
  '0': '0.875rem',
  '1': '1rem',
  '2': '1.125rem',
  '3': '1.25rem',
  '4': '1.375rem',
  '5': '1.5rem',
  '6': '1.625rem',
  '7': '1.75rem',
  '8': '2rem',
  '9': '2.25rem',
  '10': '3.25rem',
  '11': '3.875rem',
};

export const COLORS = {
  black: '#121212',
  primary: {
    50: '#f3f6f5',
    100: '#f2fcf7',
    200: '#d0f2e3',
    300: '#96E3BF',
    400: '#6DD8A6',
    500: '#14C072',
    600: '#13B46C',
    700: '#13A060',
    800: '#108450',
    900: '#0D7748',
  },
  gray: {
    50: '#F9FAF9',
    100: '#F1F3F3',
    200: '#DCE2DF',
    300: '#CDD5D1',
    400: '#BBC6C1',
    500: '#5F6D65',
    600: '#4C5751',
    700: '#3B443F',
    800: '#28332D',
    900: '#18251E',
  },
  red: {
    50: '#FDF6F6',
    100: '#FEE1E1',
    200: '#FEB2B2',
    300: '#E5817C',
    400: '#E26F6A',
    500: '#DC544C',
    600: '#D83F37',
    700: '#C82F28',
    800: '#B82119',
    900: '#A7130C',
  },
  blue: {
    50: '#F0F4FA',
    100: '#DAE6F3',
    200: '#B6CDE7',
    300: '#91B3DA',
    400: '#5F90C9',
    500: '#3D76B8',
    600: '#396FAC',
    700: '#2A517F',
    800: '#24466C',
    900: '#1C3654',
  },
};

export const BREAKPOINTS = {
  sm: BREAKPOINT_SM,
  md: BREAKPOINT_MD,
  lg: BREAKPOINT_LG,
  xl: BREAKPOINT_XL,
};

export const RADII = {
  none: '0',
  sm: '0.125rem',
  base: '0.25rem',
  md: '0.375rem',
  lg: '0.5rem',
  xl: '0.75rem',
  '2xl': '1.25rem',
  '3xl': '1.5rem',
  full: '9999px',
};

export const Z_INDICES = {
  hide: -1,
  auto: 'auto',
  base: 0,
  aboveBase: 1,
  docked: 10,
  dropdown: 1000,
  sticky: 1100,
  banner: 1200,
  overlay: 1300,
  modal: 1400,
  popover: 1500,
  skipLink: 1600,
  toast: 1700,
  tooltip: 1800,
};

export const SPACE = {
  px: '1px',
  0.5: '0.125rem',
  1: '0.25rem',
  1.5: '0.375rem',
  2: '0.5rem',
  2.5: '0.625rem',
  3: '0.75rem',
  3.5: '0.875rem',
  4: '1rem',
  5: '1.25rem',
  6: '1.5rem',
  7: '1.75rem',
  8: '2rem',
  9: '2.25rem',
  10: '2.5rem',
  12: '3rem',
  14: '3.5rem',
  16: '4rem',
  20: '5rem',
  24: '6rem',
  28: '7rem',
  32: '8rem',
  36: '9rem',
  40: '10rem',
  44: '11rem',
  48: '12rem',
  52: '13rem',
  56: '14rem',
  60: '15rem',
  64: '16rem',
  72: '18rem',
  80: '20rem',
  96: '24rem',
  136: '34rem',
};

export const SIZES_ONLY = {
  max: 'max-content',
  min: 'min-content',
  full: '100%',
  '3xs': '14rem',
  '2xs': '16rem',
  xs: '20rem',
  sm: '24rem',
  md: '28rem',
  lg: '32rem',
  xl: '36rem',
  '2xl': '42rem',
  '3xl': '48rem',
  '4xl': '56rem',
  '5xl': '64rem',
  '6xl': '72rem',
  '7xl': '80rem',
  '8xl': '90rem',
};
export const SIZES = {
  ...SPACE,
  ...SIZES_ONLY,
  container: {
    sm: '640px',
    md: '768px',
    lg: '1024px',
    xl: '1280px',
  },
};
